
"""
##本模块需要外部依赖的库
pip install xlrd           读数据，加快速度
pip install openpyxl       读数据和写数据，主要用于文件保存
pip install pymysql        MySQL数据库支持；如果只是本地SQLite不需要
pip install xktools
"""
"""
##实现目标：
    自动对Excel表格进行数据库导入和导出，数据加工、Excel汇总、分发，主要实现自动对应字段。
##实现思路：
    为了便于处理数据，把Excel分为基础表和汇总表。通过数据库对基础表进行处理，汇总通过Excel自身功能实现，简化对Excel的处理。
    基础表，格式为第一行数据类型（文本、数字、大文本），第二行为字段名称【可以自定义，需要设置字段类型和字段名称】。
    数据汇总，基于基础表采用Excel的汇总功能，通过模版提前设置好数据汇总，只更新基础表即可，也可以在数据库中汇总好，直接导出结果。
    根据Excel设置，自动生成创建表、插入数据、读取数据的SQL，导入数据库SQLite（MySQL），脚本自动根据字段所在的位置定位。
    到如数据库之后，在数据库中存放，加工，可以根据模版导出到Excel，不受字段所在行列限制。
    可以实现对Excel汇总合并、分发拆分。
    不同人之间，确定明确的对应格式，不论是如何更新表格式，只要字段列名称不变，就可以进行对应.Excel之间只传递基础表
    其他的表，采用自动汇总的模式。为了简化，采用SQLite进行数据交换
"""
